@@ -45,6 +45,10 @@ class Writer(object):
         indentation = self.level * 4 * ' '
         self.output.write('%s%s\n' % (indentation, code))
 
+    def getvalue(self):
+        s = self.output.getvalue()
+        self.output = StringIO()
+        return s
 
 writer = Writer()
 
@@ -181,7 +185,7 @@ class PythonToPythonJS(NodeVisitor):
             writer.write('%s = %s' % (node.targets[0].id, self.visit(node.value)))
 
     def visit_Print(self, node):
-        return 'print %s' % ', '.join(map(self.visit, node.values))
+        writer.write('print %s' % ', '.join(map(self.visit, node.values)))
 
     def visit_Str(self, node):
         return '"%s"' % node.s
@@ -301,9 +305,8 @@ class PythonToPythonJS(NodeVisitor):
 
 def main(script):
     input = parse(script)
-    tree = parse(input)
-    PythonToPythonJS().visit(tree)
-    return writer.output.getvalue()
+    PythonToPythonJS().visit(input)
+    return writer.getvalue()
 
 
 def command():
